@@ -22,15 +22,15 @@ def main():
     parser = argparse.ArgumentParser()
     parser.add_argument("station", help="station name", type=str)
     parser.add_argument("year", help="year", type=int)
-    parser.add_argument("doy1", help="start day of year", type=int)
-    parser.add_argument("snrEnd", help="snr ending", type=str)
+    parser.add_argument("doy", help="start day of year", type=int)
 # optional arguments
-    parser.add_argument("-orb", default='nav', type=str, help="orbit type, gps/gnss or you can specify nav,igs,igr,jax,gbm,grg,wum")
+    parser.add_argument("-snr", default=66, help="snr file ending", type=str)
+    parser.add_argument("-orb", default='nav', type=str, help="orbit type, gps, gps+glo, gnss or you can specify nav,igs,igr,jax,gbm,grg,wum")
     parser.add_argument("-rate", default='low', metavar='low',type=str, help="sample rate: low or high, only unavco")
     parser.add_argument("-dec", default=0, type=int, help="decimate (seconds)")
     parser.add_argument("-nolook", default='False', metavar='False', type=str, help="True means only use RINEX files on local machine")
     parser.add_argument("-fortran", default='True', metavar='True',type=str, help="True means use Fortran RINEX translators ")
-    parser.add_argument("-archive", default=None, metavar='all',help="archive (unavco,sopac,cddis,sonel,nz,ga,ngs)", type=str)
+    parser.add_argument("-archive", default=None, metavar='all',help="archive (unavco,sopac,cddis,sonel,nz,ga,ngs,bkg)", type=str)
     parser.add_argument("-doy_end", default=None, help="end day of year", type=int)
     parser.add_argument("-year_end", default=None, help="end year", type=int)
 
@@ -42,9 +42,9 @@ def main():
 #
     station = args.station; NS = len(station)
     if (NS == 4) or (NS == 9):
-        print('nominally valid station name')
+        print('You have submitted a nominally valid station name')
     else:
-        print('Illegal input - Station must have 4 or 9 characters')
+        print('Illegal input - Station name must have 4 or 9 characters')
         sys.exit()
     year = args.year
 
@@ -53,11 +53,11 @@ def main():
         print('Year must be four characters long: ', year)
         sys.exit()
 
-    doy1= args.doy1
-    snrt = args.snrEnd # string
-    isnr = int(snrt)
+    doy1= args.doy
+    isnr = args.snr # defined as an integer
+    #snrt = args.snrEnd # 
+    #isnr = int(snrt)
     orbtype = args.orb
-    print(orbtype)
 # currently allowed orbit types - shanghai removed 2020sep08
     orbit_list = ['gps','gps+glo','gnss','nav', 'igs','igr','jax','gbm','grg','wum']
     if orbtype not in orbit_list:
@@ -76,6 +76,7 @@ def main():
     if orbtype == 'gps+glo':
         orbtype = 'jax'
 
+    print('Orbit type:', orbtype)
     if args.fortran == 'True':
         fortran = True
     else:
